%define selinux_variants mls strict targeted

Name:		arm4
Version:	0.8.2
Release:	8%{?dist}
Summary:	Application Response Measurement V4.0

Group:		Development/System
License:	EPL
URL:		http://www.arm4.org/
Patch0:		arm4-0.8.2-fix-ant-version-check.patch
Source0:	http://downloads.sourceforge.net/arm4/arm4-%{version}.tar.gz
Source2:	arm4-README.fedora
Source3:	arm4-arm4.cron
Source4:	arm4-arm4.service

BuildRequires:	libuuid-devel openssl-devel db4-utils db4-devel libxml2-devel sqlite-devel xerces-c-devel ant ant-javadoc
BuildRequires:	systemd-units
Requires:	openssl db4 db4-cxx sqlite
Requires(pre): shadow-utils	
Requires(post): systemd-sysv
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

%description
An Open Source implementation of the Open Group's
Application Response Measurement (ARM) standard
version 4.0. The ARM agent allows you to measure
response times for related transactions across
multiple tiers in a distributed environment.

%package devel
Summary: Files needed to build applications using ARM
Requires: %{name} = %{version}-%{release}

Group: Development/Libraries

%description devel
Files needed to build programs using the Application Response Measurement
(ARM) V4.0 standard.

%package java
Summary: Java language bindings for applications using ARM
Requires: %{name} = %{version}-%{release}

Group: Development/Libraries

%description java
Files needed to build java language programs using the Application Response
Measurement (ARM) V4.0 standard.

#
# Location of agent databases
%define contentdir %{_localstatedir}/lib/arm4
%define rundir %{_localstatedir}/run/arm4

%prep
%setup -q -n arm4-%{version}
%patch0 -p1 -b .antcheckfix
cp -a %{SOURCE2} README.fedora

%build
%configure --disable-static --enable-sqlite --disable-examples --disable-tests --with-jdkhome=/etc/alternatives/java_sdk
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}

# These aren't really required in the final system
rm -rf %{buildroot}%{_datadir}/aclocal

#
# Move the java documentation
mv %{buildroot}%{_datadir}/doc/%{name}-%{version} \
	%{buildroot}%{_datadir}/doc/%{name}-java-%{version}

#
# Remove development versions of libraries that aren't intended for development
rm %{buildroot}%{_libdir}/libarm4db.so
rm %{buildroot}%{_libdir}/libarm4db_bdb.so
rm %{buildroot}%{_libdir}/libarm4db_sqlite.so
rm %{buildroot}%{_libdir}/libarm4db_common.so
rm %{buildroot}%{_libdir}/libArmNative.so

#
# Remove any libtool archives
rm %{buildroot}%{_libdir}/*.la

# Make our configuration dir if it doesn't exist
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysconfdir}
install -m 644 -p %{_builddir}/%{name}-%{version}/config/arm4.conf %{buildroot}%{_sysconfdir}

install -m 755 -p %{SOURCE4} %{buildroot}%{_unitdir}/arm4.service
mkdir -p %{buildroot}%{contentdir}
mkdir -p %{buildroot}%{rundir}

# Install a cron job to archive and age data
mkdir -p %{buildroot}%{_sysconfdir}/cron.daily
install -m 755 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/cron.daily/arm4.cron

%pre
# Add the arm4 user and group
getent group arm4 >/dev/null || groupadd -r arm4
getent passwd arm4 >/dev/null || \
	useradd -r -g arm4 -d %{contentdir} -s /sbin/nologin \
	-c "ARM 4 Daemon" arm4
exit 0

%post 
if [ $1 -eq 1 ] ; then 
    # Initial installation 
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi
/sbin/ldconfig

%post devel -p /sbin/ldconfig

%post java -p /sbin/ldconfig

%preun
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable arm4.service > /dev/null 2>&1 || :
    /bin/systemctl stop arm4.service > /dev/null 2>&1 || :
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart arm4.service >/dev/null 2>&1 || :
fi
/sbin/ldconfig

%postun devel -p /sbin/ldconfig

%postun java -p /sbin/ldconfig

%triggerun -- arm4 < 0.8.2-7
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply arm4
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save arm4 >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del arm4 >/dev/null 2>&1 || :
/bin/systemctl try-restart arm4.service >/dev/null 2>&1 || :

%files
%doc README README.fedora COPYING
%{_bindir}/arm4_control
%{_bindir}/arm4_daemon
%{_bindir}/arm4_dump
%{_bindir}/arm4_export
%{_bindir}/arm4_report
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_libdir}/libarm4db.*
%{_libdir}/libarm4db_bdb.*
%{_libdir}/libarm4db_sqlite.*
%{_libdir}/libarm4db_common.*
# The .so file is included here and not in the -devel package
# as many applications link against these libraries dynamically,
# and it is required by the standard
%{_libdir}/libarm4.so*
%{_libdir}/libarm4_null.so*
%config(noreplace) %{_sysconfdir}/arm4.conf
%{_unitdir}/arm4.service
%{_sysconfdir}/cron.daily/arm4.cron
%attr(755,arm4,arm4) %dir %{contentdir}
#%attr(755,arm4,arm4) %dir %{contentdir}/data
#%attr(1777,arm4,arm4) %dir %{contentdir}/queue
%attr(755,arm4,arm4) %dir %{rundir}
%{_datadir}/%{name}-%{version}/arm4db.xsd

%files devel
%{_includedir}/*
%{_mandir}/man3/*

%files java
%{_datadir}/doc/%{name}-java-%{version}/apidocs
%{_libdir}/arm4*
%{_libdir}/libArmNative.*

%changelog
* Fri Sep  9 2011 Tom Callaway <spot@fedoraproject.org> - 0.8.2-8
- add missing systemd scriptlets

* Thu Sep  8 2011 Tom Callaway <spot@fedoraproject.org> - 0.8.2-7
- convert to systemd

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 0.8.2-5
- rebuilt with new openssl

* Sat Aug 8 2009 David Carter <dcarter@entertain-me.com> - 0.8.2-3
- New tag to correct CVS sync issues

* Thu Aug 6 2009 David Carter <dcarter@entertain-me.com> - 0.8.2-3
- Fix bug 511471 Incorrect dependencies caused a failure to build from source

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun May 3 2009 David Carter <dcarter@entertain-me.com> - 0.8.2-1
- Improved stability and performance
- Assorted bug fixes

* Fri Apr 3 2009 David Carter <dcarter@entertain-me.com> - 0.8.1-0.7
- Missing jni.h caused build issues with F-11 F-12

* Sun Nov 30 2008 David Carter <dcarter@entertain-me.com> - 0.8.1-0.6
- Updated to latest release, which removed arm4sdk and all references
- Removed static library versions
- arm4-tests removed until new tests can be added that don't depend on the SDK

* Sat Nov 1 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.5
- Removed assertions that caused early exit from libraries

* Mon Oct 27 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.4
- Update to latest release version
- Includes more documentation and many bug fixes. SE Linux support is
  removed as it's not yet complete.

* Thu Oct 2 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.3.final
- Update to latest beta version
- Includes more documentation and many bug fixes, selinux rules

* Mon Sep 4 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.2.beta3
- Update to latest beta version
- Includes more documentation and many bug fixes

* Sun Aug 3 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.1.beta2
- Initial packaging as RPM
